Enum repr::adt::array::InvalidArrayError [−][src]
pub enum InvalidArrayError {
TooManyDimensions(usize),
WrongCardinality {
actual: usize,
expected: usize,
},
}Expand description
An error that can occur when constructing an array.
Variants
TooManyDimensions(usize)
Tuple Fields
0: usizeThe number of dimensions in the array exceedes [MAX_ARRAY_DIMENSIONS].
WrongCardinality
The number of array elements does not match the cardinality derived from its dimensions.