Enum repr::adt::datetime::TimePartFormat [−][src]
enum TimePartFormat {
SqlStandard(DateTimeField),
PostgreSql(DateTimeField),
}Expand description
Interval strings can be presented in one of two formats:
- SQL Standard, e.g.
1-2 3 4:5:6.7 - PostgreSQL, e.g.
1 year 2 months 3 daysTimePartFormat indicates which type of parsing to use and encodes a DateTimeField, which indicates “where” you should begin parsing the associated tokens w/r/t their respective syntax.
Variants
SqlStandard(DateTimeField)
Tuple Fields
PostgreSql(DateTimeField)
Tuple Fields