Enum repr::adt::datetime::Timezone [−][src]
pub enum Timezone {
FixedOffset(FixedOffset),
Tz(Tz),
}Expand description
Parsed timezone.
Variants
FixedOffset(FixedOffset)
Tuple Fields
0: FixedOffsetTz(Tz)
Tuple Fields
0: TzTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Adds names and types of the fields of the struct or enum to rti. Read more
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more