Struct repr::adt::datetime::AnnotatedIntervalPart [−][src]
struct AnnotatedIntervalPart {
pub tokens: VecDeque<TimeStrToken>,
pub fmt: TimePartFormat,
}Expand description
AnnotatedIntervalPart contains the tokens to be parsed, as well as the format to parse them.
Fields
tokens: VecDeque<TimeStrToken>fmt: TimePartFormatTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.