Struct repr::adt::jsonb::Jsonb [−][src]
pub struct Jsonb {
row: Row,
}Expand description
An owned JSON value backed by a Row.
Similar to serde_json::Value, but the conversion to Row is free.
All numbers are represented as f64s. It is not possible to construct a
Jsonb from a JSON object that contains integers that cannot be represented
exactly as f64s.
Fields
row: RowImplementations
Constructs a new Jsonb from a serde_json::Value.
Errors if any of the contained integers cannot be represented exactly as
an f64.
Parses a Jsonb from a byte slice buf.
Errors if the slice is not valid JSON or if any of the contained
integers cannot be represented exactly as an f64.
Constructs a JsonbRef that references the JSON in this Jsonb.