Function repr::adt::numeric::cx_agg [−][src]
pub fn cx_agg() -> Context<NumericAgg>Expand description
Returns a new context appropriate for operating on numeric aggregates.
pub fn cx_agg() -> Context<NumericAgg>Returns a new context appropriate for operating on numeric aggregates.