Function repr::row::row_size [−][src]
pub fn row_size<'a, I>(a: I) -> usize where
I: IntoIterator<Item = Datum<'a>>, Expand description
Return the number of bytes these Datums would use if packed as a Row.
pub fn row_size<'a, I>(a: I) -> usize where
I: IntoIterator<Item = Datum<'a>>, Return the number of bytes these Datums would use if packed as a Row.