Struct repr::DatumMap [−][src]
A mapping from string keys to Datums
Fields
data: &'a [u8]Points at the serialized datums, which should be sorted in key order
Implementations
pub fn iter(&self) -> DatumDictIter<'a>ⓘNotable traits for DatumDictIter<'a>impl<'a> Iterator for DatumDictIter<'a> type Item = (&'a str, Datum<'a>);
impl<'a> Iterator for DatumDictIter<'a> type Item = (&'a str, Datum<'a>);Trait Implementations
Try to convert a Result whose Ok variant is a Datum into this native Rust type (Self). If it fails the error variant will contain the original result. Read more
Convert this Rust type into a Result containing a Datum, or an error
type IntoIter = DatumDictIter<'a>
type IntoIter = DatumDictIter<'a>
Which kind of iterator are we turning this into?
fn into_iter(self) -> DatumDictIter<'a>ⓘNotable traits for DatumDictIter<'a>impl<'a> Iterator for DatumDictIter<'a> type Item = (&'a str, Datum<'a>);
fn into_iter(self) -> DatumDictIter<'a>ⓘNotable traits for DatumDictIter<'a>impl<'a> Iterator for DatumDictIter<'a> type Item = (&'a str, Datum<'a>);
impl<'a> Iterator for DatumDictIter<'a> type Item = (&'a str, Datum<'a>);Creates an iterator from a value. Read more
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more