Struct repr::RowRef [−][src]
A wrapper around a byte slice that guarantees the data are row-formatted.
This type exists to allow row-formatted data to be stored in types that
need not contain a Row, for example large contiguous [u8] allocations.
It is not expected that most users will use this type, especially as its
only constructor is unsafe.
Fields
data: [u8]Implementations
Construct a RowRef from a byte slice.
Safety
This method is unsafe because if the byte slice is not a valid row encoding, then unpacking its contents can cause undefined behavior.
Unpack self into a Vec<Datum> for efficient random access.
Return the first Datum in self
Panics if the Row is empty.
pub fn iter(&self) -> DatumListIter<'_>ⓘNotable traits for DatumListIter<'a>impl<'a> Iterator for DatumListIter<'a> type Item = Datum<'a>;
pub fn iter(&self) -> DatumListIter<'_>ⓘNotable traits for DatumListIter<'a>impl<'a> Iterator for DatumListIter<'a> type Item = Datum<'a>;
Notable traits for DatumListIter<'a>
impl<'a> Iterator for DatumListIter<'a> type Item = Datum<'a>;Iterate the Datum elements of the Row.
For debugging only